import { jsxs as _jsxs, jsx as _jsx } from "react/jsx-runtime";
import { useRef } from 'react';
import dayjs from 'dayjs';
import { observer } from 'mobx-react-lite';
import { Typography } from '@mui/material';
import { DateTimePicker } from '@mui/x-date-pickers';
import { AdapterDayjs } from '@mui/x-date-pickers/AdapterDayjs';
import { LocalizationProvider } from '@mui/x-date-pickers/LocalizationProvider';
import { DateFormat } from '../../constants/date-time-constants';
import { translate } from '../../locales/translations';
import './adminDateTimePicker-styles.scss';
const AdminDateTimePicker = observer((props) => {
    const { dateFormat = DateFormat.FullDateWithTime, helperText = 'Please select valid date', onChange = () => { }, error = false, isLabelError = false, isOptional = false, label = '', placeholder = 'Select date', value, dateViews = ['year', 'month', 'day', 'hours', 'minutes'], minDate = null, maxDate = null, } = props;
    const pickerRef = useRef(null);
    const errorToShow = error && helperText ? helperText : '';
    const labelClassName = isLabelError ? 'errorDateLabel' : 'dateLabel';
    const handleDatePickerChange = (dateObj) => {
        const formattedDate = dayjs(dateObj).format(dateFormat);
        if (dateFormat === DateFormat.ISO8601) {
            onChange(dayjs(dateObj).toISOString());
            return;
        }
        else {
            onChange(formattedDate);
        }
    };
    const slotProps = {
        textField: {
            placeholder,
            error,
            helperText: `${errorToShow}`,
            FormHelperTextProps: { className: `adminDatePicker____errorDateLabel` },
            className: error
                ? 'adminDatePicker__errorDatePickerInput'
                : 'adminDatePicker__datePickerInput',
        },
        actionBar: { actions: ['clear', 'cancel', 'accept'] },
    };
    return (_jsxs("div", { className: "adminDatePicker__datePickerContainer", children: [_jsxs(Typography, { className: `adminDatePicker__${labelClassName}`, children: [label, isOptional && (_jsxs("span", { className: "adminDatePicker__optionalLabel", children: ["(", translate.common.optional, ")"] }))] }), _jsx(LocalizationProvider, { dateAdapter: AdapterDayjs, children: _jsx(DateTimePicker, { className: "adminDatePicker__datePickerContainer", format: DateFormat.FullDateWithTime, onChange: handleDatePickerChange, ref: pickerRef, slotProps: slotProps, value: dayjs(value, dateFormat), views: dateViews, minDate: dayjs(minDate, dateFormat), maxDate: dayjs(maxDate, dateFormat) }) })] }));
});
export default AdminDateTimePicker;
