import type { DefaultValues, FieldValues } from 'react-hook-form';
import { type Schema } from 'zod';
import { IAdminToggleProps } from '../../components/toggle/AdminToggle';
import { IAdminUploaderProps } from '../../components/uploader/AdminUploader';
import { FieldEnum } from '../../constants/common-constants';
import { type SubmitHandlerType } from '../../hoc/withCrud/WithCrud';
import { IAdminChipInputProps } from '../../types';
import type { IColumn } from '../../types/common-types';
import { type IAdminCheckboxProps } from '../checkbox/AdminCheckbox';
import { type IAdminDatePicker } from '../date-time-picker/AdminDatePicker';
import { IAdminDateTimePicker } from '../date-time-picker/AdminDateTimePicker';
import { IAdminTimePickerProps } from '../date-time-picker/AdminTimePicker';
import { type IAdminDateRangePicker } from '../date-time-range-picker/DateRangePicker';
import { type IAdminTimeRangePicker } from '../date-time-range-picker/TimeRangePicker';
import { type IAdminDropdownProps } from '../dropdown/AdminDropdown';
import { type IAdminInputProps } from '../input/AdminInput';
import { type IAdminRadioProps } from '../radio/AdminRadio';
import { type ISideDrawerProps } from '../side-drawer/AdminSideDrawer';
import { type IAdminSliderProps } from '../slider/AdminSlider';
import './adminForm-styles.scss';
interface IInputProps extends IAdminInputProps {
    fieldType: FieldEnum.Text;
}
interface IFieldNumberProps extends IAdminInputProps {
    fieldType: FieldEnum.Number;
}
interface IToggleProps extends IAdminToggleProps {
    fieldType: FieldEnum.Toggle;
}
interface IRadioProps extends IAdminRadioProps {
    fieldType: FieldEnum.Radio;
}
interface ICheckboxProps extends IAdminCheckboxProps {
    fieldType: FieldEnum.Checkbox;
}
interface IDropDownProps extends IAdminDropdownProps {
    fieldType: FieldEnum.Dropdown;
}
interface IDatePicker extends IAdminDatePicker {
    fieldType: FieldEnum.Date;
}
interface IDateRangePicker extends IAdminDateRangePicker {
    fieldType: FieldEnum.DateRange;
}
interface ITimePicker extends IAdminTimePickerProps {
    fieldType: FieldEnum.Time;
}
interface ITimeRangePicker extends IAdminTimeRangePicker {
    fieldType: FieldEnum.TimeRange;
}
interface ISliderProps extends IAdminSliderProps {
    fieldType: FieldEnum.Slider;
}
interface IDateTimePicker extends IAdminDateTimePicker {
    fieldType: FieldEnum.DateTime;
}
interface IUploaderProps extends Omit<IAdminUploaderProps, 'onChange' | 'value'> {
    fieldType: FieldEnum.UPLOADER;
}
interface IChipInputProps extends IAdminChipInputProps {
    fieldType: FieldEnum.ChipInput;
}
export type FieldPropsType = IInputProps | IRadioProps | ICheckboxProps | IDropDownProps | IDatePicker | ITimePicker | IDateRangePicker | ITimeRangePicker | ISliderProps | IToggleProps | IFieldNumberProps | IRepeaterProps | IDateTimePicker | IUploaderProps | IChipInputProps;
interface IRepeaterFields {
    field: string;
    headerName?: string;
    fieldProps?: FieldPropsType;
}
interface IRepeaterProps {
    columns: IRepeaterFields[];
    fieldType: FieldEnum.REPEATER;
    initialAdded?: boolean;
    isPrimitiveArray?: boolean;
    limit: number;
}
export declare enum FormTypeEnum {
    Add = "Add",
    Edit = "Edit",
    Filter = "Filter"
}
interface IFormDrawerProps extends Pick<ISideDrawerProps, 'open' | 'onClose' | 'title'> {
    type: FormTypeEnum | null;
}
interface IFormProps<SubmitDataType extends FieldValues> {
    fields: IColumn<SubmitDataType>[];
    schema: Schema;
    defaultValues: DefaultValues<SubmitDataType>;
    submitTitle?: string;
    onSubmit: SubmitHandlerType<SubmitDataType>;
    onSecondaryButtonClick?: () => void;
    secondaryButtonTitle?: string;
    type: FormTypeEnum | null;
    isLoading?: boolean;
}
interface IAdminFormProps<SubmitDataType extends FieldValues> extends IFormDrawerProps, IFormProps<SubmitDataType> {
}
declare function AdminForm<SubmitDataType extends FieldValues>(props: IAdminFormProps<SubmitDataType>): import("react/jsx-runtime").JSX.Element;
export default AdminForm;
