import { flow, getRoot, types } from 'mobx-state-tree';
import { LOCAL_STORAGE_KEYS, ToastPreset } from '../../../constants';
import { HttpVerb, makeApiCall } from '../../../services/network/api-client';
const UserStore = types
    .model('UserStore', {
    isSignedIn: types.optional(types.boolean, false),
    isRegisterAdminLoading: types.boolean,
    isEmailExisting: types.boolean,
})
    .actions(self => {
    const { viewStore } = getRoot(self);
    const { toastStore } = viewStore;
    const { popToast } = toastStore;
    const registerNewAdmin = flow(function* registerNewAdmin(email, password, successCallback) {
        // TODO: 'Add API endpoint';
        try {
            self.isRegisterAdminLoading = true;
            const result = yield makeApiCall(HttpVerb.POST, '', { email, password });
            if (result) {
                successCallback && successCallback();
                popToast({
                    type: ToastPreset.Success,
                    message: 'Admin registered successfully.',
                });
            }
        }
        catch (e) {
            console.log('Error', e);
        }
        finally {
            self.isRegisterAdminLoading = false;
        }
    });
    const setIsSignedIn = (value) => {
        self.isSignedIn = value;
        localStorage.setItem(LOCAL_STORAGE_KEYS.isLoggedIn, JSON.stringify(value));
    };
    const logoutUser = () => {
        self.isSignedIn = false;
        localStorage.clear();
    };
    const checkEmailExists = flow(function* checkEmailExists(email) {
        try {
            const result = yield makeApiCall(HttpVerb.GET, '', { email });
            if (result.length > 0) {
                self.isEmailExisting = true;
                popToast({
                    type: ToastPreset.Success,
                    message: 'Email exists.',
                });
            }
            else {
                self.isEmailExisting = false;
                popToast({
                    type: ToastPreset.Error,
                    message: 'Email does not exists.',
                });
            }
        }
        catch (e) {
            console.log('Error', e);
        }
    });
    return { setIsSignedIn, logoutUser, registerNewAdmin, checkEmailExists };
});
export { UserStore };
