import { z } from 'zod';
import PeopleAltIcon from '@mui/icons-material/PeopleAlt';
import { FieldEnum } from '../../constants';
import { PaginationMethod } from '../../types/common-types';
var RewardField;
(function (RewardField) {
    RewardField["RewardUrl"] = "reward_url";
    RewardField["Rewards"] = "rewards";
})(RewardField || (RewardField = {}));
const RewardSchema = z.object({
    [RewardField.RewardUrl]: z.string().min(1, 'Reward URL is required'),
    [RewardField.Rewards]: z.array(z.any()).min(1, 'Rewards is required'),
});
export const DATA = {
    title: 'Rewards',
    tables: [
        {
            key: 'rewards',
            detailsRoute: '/rewards',
            apiEndPoint: {
                ALL: 'https://66a3354844aa637045805c36.mockapi.io/rewards',
            },
            handleDetailsSubmit: async (data) => {
                console.log('res009', data);
                return data;
            },
            columns: [
                {
                    field: RewardField.RewardUrl,
                    headerName: "Reward's URL",
                    sortable: true,
                    fieldProps: {
                        fieldType: FieldEnum.Text,
                    },
                    filterProps: {
                        fieldType: FieldEnum.Text,
                    },
                },
                {
                    field: RewardField.Rewards,
                    headerName: 'Rewards',
                    fieldProps: {
                        fieldType: FieldEnum.ChipInput,
                    },
                },
            ],
            enableExport: true,
            actions: {
                edit: true,
                delete: true,
                view: true,
                add: true,
                filter: true,
                search: false,
                toggle: false,
            },
            customActions: [
                {
                    label: 'Activate',
                    key: 'activate',
                    handleClick: (row) => {
                        console.log('Activate', row);
                    },
                    showInMenu: false,
                    Icon: PeopleAltIcon,
                },
            ],
            pagination: false,
            paginationMethod: PaginationMethod.OFFSET,
            schema: RewardSchema,
            defaultValues: {
                [RewardField.RewardUrl]: '',
                [RewardField.Rewards]: [],
            },
        },
    ],
};
