import { jsx as _jsx } from "react/jsx-runtime";
import dayjs from 'dayjs';
import { Close as CloseIcon, DoneAll as DoneAllIcon } from '@mui/icons-material';
import { AdminAnimatedStatus, AdminAvatar, AdminChip } from '../components';
import { COMMON_STYLE, DateFormat, TableCellType } from '../constants';
import palette from '../theme/colors';
export const renderCell = (params, column) => {
    const type = column?.renderCellProps?.type;
    switch (type) {
        case TableCellType.IMAGE:
            return (_jsx(AdminAvatar, { src: params.value, name: params?.row?.full_name, ...column?.renderCellProps }));
        case TableCellType.DATE:
            return _jsx("span", { children: dayjs(params.value).format(DateFormat.LL) });
        case TableCellType.DATE_TIME:
            return _jsx("span", { children: dayjs(params.value).format(DateFormat.DateTimeFormat) });
        case TableCellType.CHIP:
            return _jsx(AdminChip, { label: params.value, ...column?.renderCellProps });
        case TableCellType.ANIMATED_STATUS:
            return _jsx(AdminAnimatedStatus, { value: params.value, ...column?.renderCellProps });
        case TableCellType.BOOLEAN:
            return (_jsx("div", { style: COMMON_STYLE, children: !!params.value ? (_jsx(DoneAllIcon, { sx: {
                        color: palette.toastSuccessBackground,
                    } })) : (_jsx(CloseIcon, { sx: {
                        color: palette.error,
                    } })) }));
        default:
            return _jsx("span", { children: params.value });
    }
};
export const filterRowIfEmpty = (rows) => {
    return rows?.map(row => {
        return Object.keys(row).reduce((acc, key) => {
            acc[key] =
                row[key] === '' || row[key] === null || row[key] === undefined ? '-' : row[key];
            return acc;
        }, { ...row });
    });
};
